package com.jqtx.windows.common.mq;

import cn.hutool.core.util.IdUtil;
import cn.hutool.core.util.ObjectUtil;
import com.alibaba.fastjson.JSON;
import com.jqtx.infrastructure.mq.starter.annotation.MQConsumerComponent;
import com.jqtx.windows.common.mq.model.CreditResultModel;
import com.jqtx.windows.component.LoanComponent;
import com.jqtx.windows.component.enums.CreditResultStatusEnum;
import com.jqtx.windows.component.enums.ZNPostUrlEnum;
import com.jqtx.windows.component.model.LoanModel;
import com.jqtx.windows.utils.AbcHttpClient;
import com.jqtx.windows.web.response.WithdrawDetailResponse;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;

import java.time.LocalDateTime;

/**
 * 提现审核结果
 */
@Slf4j
@MQConsumerComponent(tags = "withdraw", topic = "$mq.loanTopic")
public class LoanResultListener extends AbstractMQConsumerHandler<CreditResultModel> {

    @Autowired
    private LoanComponent loanComponent;
    @Autowired
    private AbcHttpClient abcHttpClient;

    @Override
    public Class getClazz() {
        return CreditResultModel.class;
    }

    @Override
    public void run(CreditResultModel creditResultModel) throws Exception {
        LoanModel byOrderNo = loanComponent.getByOrderNo(creditResultModel.getOrderNo());
        if (ObjectUtil.isNull(byOrderNo) || !CreditResultStatusEnum.INIT.name().equals(byOrderNo.getLoanStatus())) {
            return;
        }
        WithdrawDetailResponse response = new WithdrawDetailResponse();
        if ("YES".equalsIgnoreCase(creditResultModel.getCreditStatus())) {
            byOrderNo.setLoanStatus(CreditResultStatusEnum.PASS.getCode());
            response.setStatus(1);
        }
        if ("RETRIAL".equalsIgnoreCase(creditResultModel.getCreditStatus())) {
            byOrderNo.setLoanStatus(CreditResultStatusEnum.INIT.getCode());
            response.setStatus(0);
        }
        if ("REJECT".equalsIgnoreCase(creditResultModel.getCreditStatus())) {
            byOrderNo.setLoanStatus(CreditResultStatusEnum.REFUSED.getCode());
            response.setStatus(2);
        }
        byOrderNo.setGmtModified(LocalDateTime.now());
        loanComponent.updateByLoanNo(byOrderNo);
        response.setLoanNo(byOrderNo.getLoanNo());
        response.setOrderNo(byOrderNo.getOrderNo());
        response.setRemark(creditResultModel.getMemo());
        response.setTransNo(IdUtil.fastSimpleUUID());
        abcHttpClient.postRequest(JSON.toJSONString(response), ZNPostUrlEnum.LOAN_CALL.getCode());
    }
}

